@@ -8,7 +8,7 @@ by using Dirac deltas.  For example, a, cos(a * t), sin(a * t), exp(j
 * a * t).
 
 
-Copyright 2016--2021 Michael Hayes, UCECE
+Copyright 2016--2022 Michael Hayes, UCECE
 
 """
 
@@ -20,10 +20,10 @@ Copyright 2016--2021 Michael Hayes, UCECE
 from sympy.core.function import AppliedUndef
 from sympy import sympify, pi, exp, I, oo, S, sign, sin, cos, sinh, cosh, tanh
 from sympy import DiracDelta, Heaviside, FourierTransform, Integral
-from sympy import fourier_transform as sympy_fourier_transform
+from sympy import fourier_transform as sympy_fourier_transform, Function
 from .sym import symsimplify, j
 from .transformer import BilateralForwardTransformer
-from .utils import factor_const, similarity_shift
+from .utils import factor_const, similarity_shift, expand_functions
 from .extrafunctions import rect, sincn, sincu, trap, tri
 
 __all__ = ('FT', 'IFT')
@@ -56,16 +56,14 @@ class FourierTransformer(BilateralForwardTransformer):
         if not isinstance(expr, AppliedUndef):
             self.error('Expecting function')
 
-        fsym = sympify(str(f))
-
         # Convert v(t) to V(f), etc.
         name = expr.func.__name__
         if self.is_inverse:
-            func = name[0].lower() + name[1:] + '(%s)' % f
+            func = Function(name[0].lower() + name[1:])
         else:
-            func = name[0].upper() + name[1:] + '(%s)' % f
+            func = Function(name[0].upper() + name[1:])
 
-        result = sympify(func).subs(fsym, f)
+        result = func(f)
         return result
 
     def integral(self, expr, t, f):
@@ -284,6 +282,16 @@ class FourierTransformer(BilateralForwardTransformer):
                     result *= exp(-I * 2 * pi * f / scale * shift)
                 return const * result
 
+            if expr.is_Function and expr.args[0] == t:
+                # Try to handle functions such as ramp, rampstep.
+                expr2 = expand_functions(expr, t)
+                if expr != expr2:
+                    terms = expr2.as_ordered_terms()
+                    result = 0
+                    for term in terms:
+                        result += self.term(term, t, f)
+                    return result * const
+
             # Punt and use SymPy.  Should check for t**n, t**n * exp(-a * t), etc.
             return const * self.sympy(expr, t, sf)
 
