@@ -1,7 +1,7 @@
 """
 This module defines a grammar for SPICE-like netlists.
 
-Copyright 2015--2021 Michael Hayes, UCECE
+Copyright 2015--2022 Michael Hayes, UCECE
 """
 
 # SPICE also considers = a delimiter.
@@ -91,6 +91,7 @@ TFcore: TFname Np Nm Ncp Ncm core [Value]; Transformer with core (works to DC!)
 TFtap: TFname Np Nm Ncp Ncm tap Nt Nt [Value]; Tapped transformer (works to DC!)
 TFtapcore: TFname Np Nm Ncp Ncm tapcore Nt Nt [Value]; Tapped transformer with core (works to DC!)
 TL: TLname Np Nm Ncp Ncm [Z0] [Gamma] [Length]; Transmission line
+TLlossless: TLname Np Nm Ncp Ncm lossless [Z0] [Gamma] [Length]; Lossless transmission line
 TP: TPname Np Nm Ncp Ncm; Generic two-port
 TPA: TPname Np Nm Ncp Ncm A A11 A12 A21 A22 [V1] [I1]; A-parameter two-port
 TPB: TPname Np Nm Ncp Ncm B B11 B12 B21 B22 [V2] [I2]; B-parameter two-port
@@ -99,6 +100,7 @@ TPH: TPname Np Nm Ncp Ncm H H11 H12 H21 H22 [V1] [I2]; H-parameter two-port
 TPY: TPname Np Nm Ncp Ncm Y Y11 Y12 Y21 Y22 [I1] [I2]; Y-parameter two-port
 TPZ: TPname Np Nm Ncp Ncm Z Z11 Z12 Z21 Z22 [V1] [V2]; Z-parameter two-port
 TR: TRname Pi Po [Value]; Transfer function
+TVtriode: TVname Nanode Ngrid Ncathode [mu] [gm] [Cgk] [Cga]; Thermionic valve triode
 Ubuffer: Uname buffer; Buffer
 Uinverter: Uname inverter; Inverter
 Udiffamp: Uname diffamp; Differential amplifier
@@ -168,6 +170,7 @@ nc: keyword;
 spdt: keyword;
 tap: keyword;
 tapcore: keyword;
+lossless: keyword;
 opamp: keyword;
 inamp: keyword;
 isoamp: keyword;
@@ -219,6 +222,13 @@ Z: keyword;
 P: pin; Pin
 Pi: pin; Input pin
 Po: pin; Output pin
+Nanode: node; Anode node
+Ngrid: node; Grid node
+Ncathode: node; Cathode node
+mu: value; Amplification factor
+gm: value; Transconductance
+Cgk: value; Grid to cathode capacitance
+Cga: value; Grid to anode capacitance
 Nb: node; Base node
 Nc: node; Collector node
 Ncp: node; Positive control node
