@@ -1,33 +1,16 @@
 """This module provides the Latex class for formatting
 values and labels.
 
-Copyright 2020 Michael Hayes, UCECE
+Copyright 2020--2021 Michael Hayes, UCECE
 
 """
 
-
 import re
-from .config import subscripts
+from .config import subscripts, greek_letter_names
 
 sub_super_pattern = re.compile(r"([_\^]){([a-zA-Z]+)([0-9]*)}")
-
-
-def latex_mathrm(s):
-        
-    def foo(match):
-        
-        word = match.group(2)
-        suffix = word + match.group(3)
-        
-        # Perhaps look up dictionary to find valid words?
-        # Assume that if length 3 or more then a word.
-        if word.lower() in subscripts or len(word) > 2:
-            suffix = r'{\mathrm{%s}}' % suffix
-        else:
-            suffix = r'{%s}' % suffix
-        return match.group(1) + suffix
-
-    return sub_super_pattern.sub(foo, s)
+greek_letter_name_pattern = re.compile(r"(.?)(%s)" % '|'.join(greek_letter_names))
+math_symbols_pattern = re.compile('|'.join(['_',  r'\^', r'\\left', r'\\math', r'\\frac', r'\\sqrt']))
 
 
 class Latex(object):
@@ -36,16 +19,40 @@ class Latex(object):
 
         self.str = string
 
-    def mathrm(self):
+    def mathrm(self, s):
         """Place words in sub- or super-scripts inside a mathrm.
-        For example V_{rms} -> V_{\mathrm{rms}}"""
+        For example: V_{rms} -> V_{\mathrm{rms}}"""
 
-        return latex_mathrm(self.str)
+        def foo(match):
+        
+            word = match.group(2)
+            suffix = word + match.group(3)
+        
+            # Perhaps look up dictionary to find valid words?
+            # Assume that if length 3 or more then a word.
+            if word.lower() in subscripts or len(word) > 2:
+                suffix = r'{\mathrm{%s}}' % suffix
+            else:
+                suffix = r'{%s}' % suffix
+            return match.group(1) + suffix
 
+        return sub_super_pattern.sub(foo, s)
+
+    def greek(self, s):
+        """Replace alpha with \alpha, etc."""
+
+        def foo(match):
+            if match.group(1) != '\\':
+                return match.group(1) + '\\' + match.group(2)
+            return match.group(1) + match.group(2)
+
+        return greek_letter_name_pattern.sub(foo, s)            
+    
     def __str__(self):
 
         s = self.str
-        return latex_mathrm(s)
+        s = self.greek(s)
+        return self.mathrm(s)
             
 
 def latex_str(string):
@@ -69,14 +76,16 @@ def latex_format_label(s):
     if '$' in s:
         return s
 
+    s = latex_str(s)
+    
     # If have _, ^, \frac, etc.  need to be in math-mode.
     # Should prevent lcapy generating such strings and 
     # warn user to explicity use math mode.  The tricky part is that
     # arbitrary signals may have math symbols, say sqrt.
-    math_symbols = ('_',  '^', '\\left', '\\math', '\\frac', '\\sqrt')
+    math_symbols = ('_',  '^', '\\')
     for math_symbol in math_symbols:
         if math_symbol in s:
-            return '$' + latex_str(s) + '$'
+            return '$' + s + '$'
     return s
 
 
