@@ -23,6 +23,7 @@ import lcapy
 import inspect
 import sys
 import sympy as sym
+from warnings import warn
 
 __all__ = ()
 
@@ -334,6 +335,19 @@ class Cpt(ImmittanceMixin):
         else:
             raise ValueError('%s is not a source' % self)
 
+    def in_parallel(self):
+        """Return set of components in parallel with cpt."""
+
+        return self.cct.in_parallel(self.name)
+
+    def in_series(self):
+        """Return set of components in series with cpt.  Note, this
+        does not find components that do not share a node, for example,
+        R1 and R3 are not considered as being in series for
+        R1 + (R2 | R3) + R3"""
+
+        return self.cct.in_series(self.name)
+
     @property
     def is_causal(self):
         """Return True if causal component or if source produces
@@ -681,6 +695,27 @@ class Cpt(ImmittanceMixin):
 
         return cpt in self.connected
 
+    def short(self):
+        """Apply short-circuit across component."""
+
+        parallel_set = self.in_parallel()
+        for cptname in parallel_set:
+            cpt = self.cct.elements[cptname]
+            if cpt.is_voltage_source:
+                if cpt.value == 0:
+                    warn('Component %s already shorted by %s' % (self.name, cptname))
+                else:
+                    warn('Shorting voltage source %s in parallel with %s' % (cptname, self.name))
+            elif cpt.is_current_source:
+                warn('Shorting current source %s in parallel with %s' % (cptname, self.name))
+
+        #self.cct.add('W %s %s' % (self.nodes[0].name, self.nodes[1].name))
+        # Could add zero ohm resistor but then could not determine current
+        # through the short.
+        self.cct.add('V? %s %s 0' % (self.nodes[0].name, self.nodes[1].name))
+
+        # Perhaps have option to delete component?
+
 
 class Invalid(Cpt):
 
@@ -1070,6 +1105,46 @@ class GY(Dummy):
         mna._D[m2, m2] -= Z1
 
 
+class TVtriode(Dummy):
+    """Triode"""    
+
+    need_branch_current = True
+    need_extra_branch_current = True
+
+    def _stamp(self, cct):
+        
+        n1, n2, n3= self.node_indexes
+        m1 = self.cct._branch_index(self.defname + 'X')
+        m2 = self.branch_index
+
+        # m1 is the input branch
+        # m2 is the output branch
+        # GY.I gives the current through the output branch
+
+        # Could generalise to have different input and output
+        # impedances, Z1 and Z2, but if Z1 != Z2 then the device is
+        # not passive.
+
+        # V2 = -I1 Z2     V1 = I2 Z1
+        # where V2 = V[n1] - V[n2] and V1 = V[n3] - V[n4]
+        
+        Z1 = ConstantDomainExpression(self.args[0]).expr                    
+        Z2 = Z1
+        
+        if n1 >= 0:
+            cct._B[n1, m2] += 1
+            cct._C[m1, n1] += 1
+        if n2 >= 0:
+            cct._B[n2, m2] -= 1
+            cct._C[m1, n2] -= 1
+        if n3 >= 0:
+            cct._B[n3, m1] += 1
+            cct._C[m2, n3] += 1 
+
+        cct._D[m1, m1] += Z2
+        cct._D[m2, m2] -= Z1
+
+
 class CCVS(DependentSource):
     """CCVS"""
 
@@ -1845,6 +1920,7 @@ defcpt('SWspdt', 'SW', 'SPDT switch')
 
 defcpt('TFcore', TF, 'Transformer with core')
 defcpt('TFtapcore', TFtap, 'Transformer with core')
+defcpt('TLlossless', TL, 'Lossless transmission line')
 
 defcpt('Ubuffer', Logic, 'Buffer')
 defcpt('Upbuffer', Logic, 'Buffer with power supplies')
