@@ -7,7 +7,7 @@ Copyright 2019-2021 Michael Hayes, UCECE
 
 from .circuitgraph import CircuitGraph
 from .tmatrix import TimeDomainMatrix
-from .expr import equation
+from .expr import equation, ExprTuple
 from .systemequations import SystemEquations
 import sympy as sym
 
@@ -45,13 +45,18 @@ class NodalAnalysis(object):
 
     """
 
+    @classmethod
+    def from_circuit(cls, cct, node_prefix=''):
+
+        return cls(cct, node_prefix)
+
     def __init__(self, cct, node_prefix=''):
         """`cct` is a netlist
         `node_prefix` can be used to avoid ambiguity between
         component voltages and node voltages."""
 
         self.cct = cct
-        self.cg = CircuitGraph(cct)
+        self.cg = CircuitGraph.from_circuit(cct)
 
         self.kind = self.cct.kind
         if self.kind == 'super':
@@ -207,6 +212,21 @@ class NodalAnalysis(object):
             self._sys = self._analyse()
         return self._sys.format(form, invert)
 
+    @property
+    def unknowns(self):
+        """Return tuple of the unknown voltages"""
+
+        return ExprTuple(self.y)
+
+    def solve_laplace(self):
+        """Determine the unknown voltages using Laplace transforms and
+        return as a dict"""
+
+        from .sexpr import s
+        
+        return self.nodal_equations()(s).solve(self.unknowns(s))
+    
+    
 from .expr import ExprDict, expr
 from .voltage import Vname
 from .current import Itype
