@@ -1,3 +1,9 @@
+"""This module provides the Opts class for handling schematic options.
+
+Copyright 2021 Michael Hayes, UCECE
+"""
+
+
 class Opts(dict):
 
     def __init__(self, arg=None):
@@ -84,6 +90,7 @@ class Opts(dict):
         return stripped
 
     def strip_voltage_labels(self):
+        """Strip voltage labels."""        
 
         return self.strip('v', 'vr', 'v_', 'v^', 'v_>', 'v_<', 'v^>', 'v^<')
 
@@ -100,6 +107,7 @@ class Opts(dict):
         return self.strip('l', 'l^', 'l_')
 
     def strip_all_labels(self):
+        """Strip voltage, current, flow, and labels."""
 
         stripped = Opts()
         
