@@ -412,6 +412,7 @@ class Schematic(NetfileMixin):
 
         self.elements[cpt.name] = cpt
 
+        # Perhaps don't show nodes if cpt invisible?
         if not cpt.ignore:
 
             for node in cpt.auxiliary_node_names:
@@ -441,7 +442,11 @@ class Schematic(NetfileMixin):
 
     def _positions_calculate(self, method='graph', debug=False):
 
+        if self.debug & 4:
+            print('Creating graphs')
         placer = schemplacer(self.elements, self.nodes, method, debug)
+        if self.debug & 4:
+            print('Solving graphs')
         self.width, self.height = placer.solve(self.node_spacing)
 
     def _tikz_draw(self, style_args='', **kwargs):
@@ -555,16 +560,16 @@ class Schematic(NetfileMixin):
 
         latexrunner = LatexRunner(self.debug & 2)
 
-        self.circuitikz_date, self.circuitikz_version = latexrunner.circuitikz_version()
-        if self.circuitikz_date is None:
-            raise RuntimeError('circuitikz is not installed')
-
         content = self._tikz_draw(style_args=style_args, **kwargs)
 
         if nosave:
             return
 
         if self.debug & 1:
+            self.circuitikz_date, self.circuitikz_version = latexrunner.circuitikz_version()
+            if self.circuitikz_date is None:
+                raise RuntimeError('circuitikz is not installed')
+
             print('circuitikz version %s (%s)' % (self.circuitikz_version,
                                                   self.circuitikz_date))
             print('width=%d, height=%d, dpi=%d, cpt_size=%.2f, node_spacing=%.2f, scale=%.2f'
@@ -702,9 +707,10 @@ class Schematic(NetfileMixin):
         if not self.hints:
             raise RuntimeWarning('No schematic drawing hints provided!')
 
+        png = kwargs.pop('png', False)
+        svg = kwargs.pop('svg', False)
+
         if in_ipynb() and filename is None:
-            png = 'png' in kwargs and kwargs.pop('png')
-            svg = 'svg' in kwargs and kwargs.pop('svg')
 
             if not png and not svg:
                 svg = False
