@@ -1,50 +1,23 @@
 """This module implements the LaplaceDomainMatrix class for a matrix of
 Laplace-domain expressions.
 
-Copyright 2019--2020 Michael Hayes, UCECE
+Copyright 2019--2021 Michael Hayes, UCECE
 
 """
 
 from .matrix import Matrix
-from .inverse_laplace import inverse_laplace_transform
-
 
 class LaplaceDomainMatrix(Matrix):
     from .sexpr import LaplaceDomainExpression    
     _typewrap = LaplaceDomainExpression
 
-    def inverse_laplace(self, **assumptions):
+    def ILT(self, **assumptions):
 
-        def ilt(expr):
-            from .sym import ssym, tsym
-            return inverse_laplace_transform(expr, ssym, tsym, **assumptions)
+        def func(expr):
+            return expr.ILT(**assumptions)
         
-        return TimeDomainMatrix(self.applyfunc(ilt))
+        return TimeDomainMatrix(self.applyfunc(func))
 
-    def canonical(self):
-
-        return self.applyfunc(self._typewrap.canonical)
-
-    def general(self):
-
-        return self.applyfunc(self._typewrap.general)
-
-    def mixedfrac(self):
-
-        return self.applyfunc(self._typewrap.mixedfrac)
-
-    def partfrac(self):
-
-        return self.applyfunc(self._typewrap.partfrac)
-
-    def timeconst(self):
-
-        return self.applyfunc(self._typewrap.timeconst)   
-
-    def ZPK(self):
-
-        return self.applyfunc(self._typewrap.ZPK)    
-    
 
 class LaplaceDomainVoltageMatrix(LaplaceDomainMatrix):
     from .sexpr import LaplaceDomainVoltage    
