@@ -57,6 +57,13 @@ class LcapyCoreTester(unittest.TestCase):
         self.assertEqual2(a.sign, expr(j), "sign incorrect.")
         self.assertEqual2(-a.sign, expr(-j), "sign incorrect.")
 
+        n = s + 2
+        d = (s + 3) * (s + 4)
+        e = exp(-5 * s)
+        a = n * e / d
+        self.assertEqual2(a.N, n * e, "N incorrect.")
+        self.assertEqual2(a.D, d, "D incorrect.")
+
     def test_cExpr1(self):
         """Check cExpr1
 
@@ -269,6 +276,15 @@ class LcapyCoreTester(unittest.TestCase):
         self.assertEqual(a.evaluate(2), 4.0, "scalar evaluate incorrect.")
         self.assertEqual(a.evaluate((2, 3))[1], 9.0, "vector evaluate incorrect.")
 
+    def test_expr(self):
+        """Check expr
+        """
+
+        e = expr('rect(t)')
+        self.assertEqual(e, rect(t), "expr('rect(t)'")
+        e = expr('tri(t)')
+        self.assertEqual(e, tri(t), "expr('tri(t)'")
+
     def test_step(self):
         """Check step
 
