@@ -29,9 +29,12 @@ class LcapyTester(unittest.TestCase):
         self.assertEqual(nexpr('delta(n - 2)').DFT(),
                          kexpr('exp(-j * 2 * pi * 2 * k / N)'), "delta(n - 2)")
 
+        # Temp. hack, ideally should get result 2 * N * delta(k + 1)
         self.assertEqual(nexpr('2 * exp(-j * 2 * pi * n / N)').DFT(), 
-                         kexpr('2 * N * delta(k - 1)'), "2 * exp(-j * 2 * pi * n / N)")
-
+                         kexpr('2 * N * delta(k + 1 - N)'), "2 * exp(-j * 2 * pi * n / N)")
+        self.assertEqual(nexpr('x(n-1)').DFT(N=2), 
+                         kexpr('X(k)*exp(-j * pi * k)'), "x(n-1)")
+        
 
     def test_IDFT(self):
 
@@ -43,7 +46,7 @@ class LcapyTester(unittest.TestCase):
 
         X1 = DFTmatrix(4)
         X2 = Matrix(((1, 1, 1, 1), (1, -j, -1, j), (1, -1, 1, -1), (1, j, -1, -j)))
-        X3 = IDFTmatrix(4).conjugate * 4
+        X3 = IDFTmatrix(4).conj * 4
         
         self.assertEqual(X1, X2, "DFTmatrix(4)")
         self.assertEqual(X3, X2, "IDFTmatrix(4)")        
