@@ -18,12 +18,17 @@ class LcapyTester(unittest.TestCase):
         self.assertEqual(TimeDomainVoltage('x(t)').laplace(), LaplaceDomainVoltage('X(s)'), "x(t)")
         self.assertEqual(TimeDomainVoltage('5 * x(t)').laplace(), LaplaceDomainVoltage('5 * X(s)'), "5 * x(t)")
 
-        v = expr('R0 * exp(-alpha * t) * i(t)') 
+        v = expr('R0 * exp(-alpha * t) * i(t)')
         V = expr('R0 * I(s + alpha)')
 
         self.assertEqual(v.laplace(), V, "R0 * exp(-alpha * t) * i(t)")
-        
-        
+
+        self.assertEqual(rect(t - 0.5).laplace(), (1 - exp(-s)) / s, "rect(t)")
+        self.assertEqual(rect(t / 2 - 0.5).laplace(), (1 - exp(-2 * s)) / s, "rect(t / 2)")
+        self.assertEqual(ramp(t).laplace(), 1 / s**2, "ramp(t)")
+        self.assertEqual(rampstep(t).laplace(), (1 - exp(-s)) / s**2, "rampstep(t)")
+
+
     def test_inverse_laplace(self):
 
         self.assertEqual((1 / s).inverse_laplace(causal=True), Heaviside(t),
@@ -31,7 +36,7 @@ class LcapyTester(unittest.TestCase):
         self.assertEqual((s * 0 + 1).inverse_laplace(causal=True), DiracDelta(t),
                          "1")
         self.assertEqual((s).inverse_laplace(causal=True), DiracDelta(t, 1),
-                         "s")        
+                         "s")
         self.assertEqual((s * 0 + 10).inverse_laplace(causal=True), 10
                          * DiracDelta(t), "10")
         self.assertEqual(LaplaceDomainVoltage('V(s)').inverse_laplace(causal=True),
@@ -43,8 +48,8 @@ class LcapyTester(unittest.TestCase):
                          TimeDomainVoltage('v(t)'), "v(t)")
         self.assertEqual(expr('1/(s+a)').inverse_laplace(causal=True), expr('exp(-a * t) * u(t)'), "1/(s+a)")
         self.assertEqual(expr('1/(s**2)').inverse_laplace(causal=True), expr('t * u(t)'), "1/(s**2)")
-        self.assertEqual(expr('1/((s+3)**2)').inverse_laplace(causal=True), expr('t * u(t) * exp(-3 * t)'), "1/((s+3)**2)")        
-        self.assertEqual(expr('1/(s**3)').inverse_laplace(causal=True), expr('t**2 * u(t) / 2'), "1/(s**3)")                
+        self.assertEqual(expr('1/((s+3)**2)').inverse_laplace(causal=True), expr('t * u(t) * exp(-3 * t)'), "1/((s+3)**2)")
+        self.assertEqual(expr('1/(s**3)').inverse_laplace(causal=True), expr('t**2 * u(t) / 2'), "1/(s**3)")
         self.assertEqual(expr('s/(s+a)').inverse_laplace(causal=True), expr('-a * exp(-a * t) * u(t) + delta(t)'), "s/(s+a)")
         self.assertEqual(expr('s/(s**2+a**2)').inverse_laplace(causal=True), expr('cos(a * t) * u(t)'), "s/(s**2+a**2)")
         self.assertEqual(expr('a/(s**2+a**2)').inverse_laplace(causal=True), expr('sin(a * t) * u(t)'), "a/(s**2+a**2)")
@@ -59,11 +64,11 @@ class LcapyTester(unittest.TestCase):
 
         self.assertEqual(expr('s*(1/s - exp(-5*s)/s)/(s + 1)').expand().ILT(causal=True),
                          expr('-exp(5 - t)*u(t - 5) + exp(-t)*u(t)'),
-                         "'s*(1/s - exp(-5*s)/s)/(s + 1)")        
+                         "'s*(1/s - exp(-5*s)/s)/(s + 1)")
 
         A4 = (1/s - exp(-5*s)/s)/(s**2 + 707*s/500 + 1)
         self.assertEqual(A4(t)(s), A4, str(A4))
-        
+
     def test_damped_sin(self):
 
         H1 = 2 / (2 * s ** 2 + 5 * s + 6)
@@ -75,7 +80,7 @@ class LcapyTester(unittest.TestCase):
         self.assertEqual(H3(t, damped_sin=True)(s), H3, "damped sin3")
         self.assertEqual((H1 + H2)(t, damped_sin=True)(s), H1 + H2, "damped sin1, 2")
         self.assertEqual((H1 + H3)(t, damped_sin=True)(s), H1 + H3, "damped sin1, 3")
-        self.assertEqual((H1 + H2 + H3)(t, damped_sin=True)(s), H1 + H2 + H3, "damped sin1, 2, 3")                
+        self.assertEqual((H1 + H2 + H3)(t, damped_sin=True)(s), H1 + H2 + H3, "damped sin1, 2, 3")
 
 
     def test_derivative_undef(self):
@@ -90,7 +95,7 @@ class LcapyTester(unittest.TestCase):
         h = H(t)
         H2 = h(s)
 
-        self.assertEqual(H, H2, "second derivative of undef")                
+        self.assertEqual(H, H2, "second derivative of undef")
 
     def test_laplace_convolution(self):
 
@@ -107,13 +112,13 @@ class LcapyTester(unittest.TestCase):
         self.assertEqual(a(s), expr('3 * X(s) / s'), "3 * X / s")
 
         a = expr('Integral(3 * x(tau), (tau, 0, t))')
-        self.assertEqual(a(s), expr('3 * X(s) / s'), "3 * X / s")        
-        
+        self.assertEqual(a(s), expr('3 * X(s) / s'), "3 * X / s")
+
         a = expr('x(t)').convolve(expr('g(t)'))
         self.assertEqual(a(s), expr('X(s) * G(s)'), "X(s) * G(s)")
 
         a = expr('x(t)').convolve(expr('g(t)'), commutate=True)
-        self.assertEqual(a(s), expr('X(s) * G(s)'), "X(s) * G(s)")        
+        self.assertEqual(a(s), expr('X(s) * G(s)'), "X(s) * G(s)")
 
         a = expr('x(t)').convolve(expr('g(t)', causal=True))
         self.assertEqual(a(s), expr('X(s) * G(s)'), "X(s) * G(s)")
@@ -132,6 +137,4 @@ class LcapyTester(unittest.TestCase):
 
         a = expr('x(t)', causal=True).convolve(expr('g(t)', causal=True,
                                                     commutate=True))
-        self.assertEqual(a(s), expr('X(s) * G(s)'), "X(s) * G(s)")                                                                                               
-
-
+        self.assertEqual(a(s), expr('X(s) * G(s)'), "X(s) * G(s)")
