@@ -17,8 +17,9 @@ class LcapyTester(unittest.TestCase):
 \usepackage{amsmath}
 \usepackage{circuitikz}
 \usetikzlibrary{fit, shapes, arrows, patterns, decorations.text, decorations.markings}
+
 \begin{document}
-\begin{tikzpicture}[scale=1.00, transform shape, /tikz/circuitikz/bipoles/length=1.50cm, american currents, american voltages]
+\begin{tikzpicture}[scale=1.00, transform shape, /tikz/circuitikz/bipoles/length=1.50cm, american currents, american voltages, voltage dir=RP]
   \coordinate (1) at (0,0);
   \coordinate (2) at (2,0);
   \coordinate (3) at (3,0);
@@ -30,11 +31,10 @@ class LcapyTester(unittest.TestCase):
   \draw (0) node[ocirc] {};
 \end{tikzpicture}
 \end{document}"""
-        
+
         content = open('tmp.tex').read()
         if content != match:
-            raise Error('Schematic mismatch')
-
+            raise ValueError('Schematic mismatch')
 
     def test_schematic2(self):
 
@@ -48,8 +48,9 @@ C 1 3 3; right""")
 \usepackage{amsmath}
 \usepackage{circuitikz}
 \usetikzlibrary{fit, shapes, arrows, patterns, decorations.text, decorations.markings}
+
 \begin{document}
-\begin{tikzpicture}[scale=1.00, transform shape, /tikz/circuitikz/bipoles/length=1.50cm, american currents, american voltages]
+\begin{tikzpicture}[scale=1.00, transform shape, /tikz/circuitikz/bipoles/length=1.50cm, american currents, american voltages, voltage dir=RP]
   \coordinate (1) at (0,0);
   \coordinate (2) at (2,0);
   \coordinate (3) at (4,0);
@@ -70,11 +71,11 @@ C 1 3 3; right""")
   \draw[anchor=south east] (3) node {3};
 \end{tikzpicture}
 \end{document}"""
-        
+
         content = open('tmp.tex').read()
         if content != match:
-            raise Error('Schematic mismatch')
-        
+            raise ValueError('Schematic mismatch')
+
     def test_network_node_positions1(self):
 
         a = R(1) + C(2)
@@ -85,7 +86,7 @@ C 1 3 3; right""")
         self.assertEqual(nodes['1'].pos.x, 0, '1 x')
         self.assertEqual(nodes['2'].pos.x, 2, '2 x')
         self.assertEqual(nodes['3'].pos.x, 3, '3 x')
-        self.assertEqual(nodes['0'].pos.x, 5, '0 x')        
+        self.assertEqual(nodes['0'].pos.x, 5, '0 x')
 
     def test_network_node_positions2(self):
 
@@ -102,8 +103,8 @@ C 1 3 3; right""")
         self.assertEqual(nodes['6'].pos.x, 3, '6 x')
         self.assertEqual(nodes['7'].pos.x, 4, '7 x')
         self.assertEqual(nodes['8'].pos.x, 1, '8 x')
-        self.assertEqual(nodes['9'].pos.x, 6, '9 x')        
-        self.assertEqual(nodes['0'].pos.x, 7, '0 x')        
+        self.assertEqual(nodes['9'].pos.x, 6, '9 x')
+        self.assertEqual(nodes['0'].pos.x, 7, '0 x')
 
     def test_network_danglin3(self):
 
@@ -119,7 +120,7 @@ R7 7 8; right=2, fixed""")
         sch = a.sch
         sch._positions_calculate()
         nodes = sch.nodes
-        
+
         self.assertEqual(nodes['1'].pos.x, 2, '1 x')
         self.assertEqual(nodes['2'].pos.x, 4, '2 x')
         self.assertEqual(nodes['3'].pos.x, 6, '3 x')
@@ -128,5 +129,3 @@ R7 7 8; right=2, fixed""")
         self.assertEqual(nodes['6'].pos.x, 6, '6 x')
         self.assertEqual(nodes['7'].pos.x, 4, '7 x')
         self.assertEqual(nodes['8'].pos.x, 8, '8 x')
-
-        
