@@ -1,7 +1,7 @@
 """This module provides the TimeDomainExpression class to represent
 time domain expressions.
 
-Copyright 2014--2021 Michael Hayes, UCECE
+Copyright 2014--2022 Michael Hayes, UCECE
 
 """
 
@@ -110,6 +110,13 @@ class TimeDomainExpression(TimeDomain, Expr):
 
         return self.FT(var, evaluate, **assumptions)
 
+    def norm_fourier(self, evaluate=True, **assumptions):
+        """Attempt normalized Fourier transform."""
+
+        from .symbols import F
+
+        return self.FT(F, evaluate, **assumptions)
+
     def angular_fourier(self, evaluate=True, **assumptions):
         """Attempt angular Fourier transform."""
 
@@ -134,11 +141,12 @@ class TimeDomainExpression(TimeDomain, Expr):
         maximum value with the minimum value set to 0.
 
         kwargs include:
-        axes - the plot axes to use otherwise a new figure is created
-        xlabel - the x-axis label
-        ylabel - the y-axis label
-        xscale - the x-axis scaling, say for plotting as ms
-        yscale - the y-axis scaling, say for plotting mV
+        `axes` - the plot axes to use otherwise a new figure is created
+        `xlabel` - the x-axis label
+        `ylabel` - the y-axis label
+        `xscale` - the x-axis scaling, say for plotting as ms
+        `yscale` - the y-axis scaling, say for plotting mV
+        `plot_deltas` - plot Dirac deltas as arrows
         in addition to those supported by the matplotlib plot command.
 
         The plot axes are returned."""
@@ -202,7 +210,7 @@ class TimeDomainExpression(TimeDomain, Expr):
         expr = self.expr
         if self.is_conditional:
             expr = expr.args[0].args[0]
-        expr = expr * Heaviside(t)
+        expr = expr * Heaviside(t.var)
         return self.__class__(expr)
 
     def discretize(self, method='bilinear', alpha=0.5):
