@@ -1,6 +1,6 @@
 """This module provides base transformer classes.
 
-Copyright 2020--2021 Michael Hayes, UCECE
+Copyright 2020--2022 Michael Hayes, UCECE
 
 """
 
@@ -94,12 +94,12 @@ class BilateralForwardTransformer(Transformer):
     is_bilateral = True
     is_inverse = False
 
-    def doit(self, expr, var, conjvar, evaluate=True, **kwargs):
+    def doit(self, expr, var, conjvar, evaluate=True, cache=True, **kwargs):
 
         const, expr = factor_const(expr, var)
 
         key = self.key(expr, var, conjvar, **kwargs)
-        if key in self.cache:
+        if cache and key in self.cache:
             return const * self.cache[key]
 
         expr = self.rewrite(expr, var)
@@ -190,8 +190,9 @@ class UnilateralInverseTransformer(Transformer):
 
         elif not kwargs.get('causal', False):
 
-            # Cannot determine result for var < 0
-            result = Piecewise((result, var >= 0))
+            if uresult != 0:
+                # Cannot determine result for var < 0
+                result = Piecewise((result, var >= 0))
 
         return result
 
